@@ -1,6 +1,11 @@
 from ape import plugins
 
-from .compiler import VyperCompiler
+from .compiler import VyperCompiler, VyperConfig
+
+
+@plugins.register(plugins.Config)
+def config_class():
+    return VyperConfig
 
 
 @plugins.register(plugins.CompilerPlugin)
